.. _api:

API documentation
=================

:Release: |release|
:Date: |today|

.. currentmodule:: cobyqa

This section references a manual for using COBYQA in Python.
Most users will only need to use the `minimize` function.
An :ref:`installation <installation>` guide and :ref:`usage <usage>` examples are provided in the :ref:`user guide <user>`.

.. toctree::
    :maxdepth: 2

    solver

The implementation of COBYQA is documented in the :ref:`developer guide <dev>`.
It is completely unnecessary to read the :ref:`developer guide <dev>` to use COBYQA, and it only provides insights for people interested in the development of derivative-free optimization methods such as COBYQA.
